==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/sn_network.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">

			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['section_social_network'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td width="50%" valign="top">
						<b><?php echo $lang['txt_social_network'];?></b><br />
						<?php echo $lang['txt_social_network_intro'];?>
					</td>
					<td width="50%" valign="top">
						<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture">
							<?php
							$total = 0;
							if (isset($network)) {
							
							foreach($network as $key => $i):
							?>
							<tr>
								<td class="bg3">
									<?php echo $lang['sn']['degree'][$i['degree_id']];?><br />
									<span class="txt_footer">
									<?php echo $lang['sn']['degree_desc'][$i['degree_id']];?><br />
									</span>
								</td>
								<td align="center" class="bg2" valign="middle">
									<?php 
									$sub_total = 0;
									if (isset($i['sn_total']) && $i['sn_total'] > 0) {
									    $sub_total = $i['sn_total'];
									}
									
									echo $sub_total;
									$total = $total+$sub_total;
									?>
								</td>
							</tr>
							
							
							<?php 
							endforeach;
							}?>
							
							
							
							<tr>
								<td class="bg3">
									<?php echo $lang['txt_outstanding_invites'];?><br />
									<span class="txt_footer">
									<?php echo $lang['txt_outstanding_invites_intro'];?><br />
									</span>
								</td>
								<td align="center" class="bg2" valign="middle">
									<?php 
									$sub_total = 0;
									if (isset($outstanding_invites) && $outstanding_invites > 0) {
									    $sub_total = $outstanding_invites;
									}
									
									echo $sub_total;
									$total = $total+$sub_total;
									?>
								</td>
							</tr>
							<tr>
								<td class="bg3">
									<?php echo $lang['txt_your_social_network'];?><br />
									<span class="txt_footer">
									<?php echo $lang['txt_your_social_network_intro'];?><br />
									</span>
								</td>
								<td align="center" class="bg1" valign="middle">
									<?php echo $total;?>
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_social_network1'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($friends)) {
				foreach($friends as $key => $i):
				?>
				<tr>
					<td>

						<table border="0" width="100%" cellspacing="2" cellpadding="2" class="picture">
							<tr>
								<td valign="middle" width="46" align="center" height="28">
									<img src="<?php echo $templatePath;?>img/sn.png" width="28" height="28" alt="" /><br />
								</td>
								<td valign="middle" align="center" width="46" class="bg2">
									<?php echo $i['sn_total'];?><br />
								</td>
								<td valign="middle" class="bg4">
									<table border="0" width="100%" cellspacing="2" cellpadding="0">
										<tr>
											<td>
												<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><b><?php echo $i['profile_nic'];?></b></a>, 
												
												<?php echo $i['profile_create_datetime'];?>, 
												<?php echo $i['profile_hometown'];?>, 
			
												<?php
												if ($i['online_status'] == 1) {
												    echo "<span class='txt_breadcrumb_on'><b>" . $lang['arr_user_online_status'][1] . "</b></span><br />";
												}
												else {
													    echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
												}
												?>
											</td>
											<td align="right">
												<?php
												if (isset($i['profile_allow_msg']) && $i['profile_allow_msg'] == 1) {
												?>
												<a href="msg_compose.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a>&nbsp;&nbsp;<br />
												<?php }?>
											</td>
										</tr>
									</table>
								</td>
								<td valign="middle" width="32">
									<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
								</td>
							</tr>
						</table>


					</td>
				</tr>
				<tr>
					<td colspan="5">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="5">
						<?php echo $lang['err_no_friends'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

		</td>
	</tr>
</table>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/sn_network.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">

			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['section_social_network'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td width="50%" valign="top">
						<b><?php echo $lang['txt_social_network'];?></b><br />
						<?php echo $lang['txt_social_network_intro'];?>
					</td>
					<td width="50%" valign="top">
						<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture">
							<?php
							$total = 0;
							if (isset($network)) {
							
							foreach($network as $key => $i):
							?>
							<tr>
								<td class="bg3">
									<?php echo $lang['sn']['degree'][$i['degree_id']];?><br />
									<span class="txt_footer">
									<?php echo $lang['sn']['degree_desc'][$i['degree_id']];?><br />
									</span>
								</td>
								<td align="center" class="bg2" valign="middle">
									<?php 
									$sub_total = 0;
									if (isset($i['sn_total']) && $i['sn_total'] > 0) {
									    $sub_total = $i['sn_total'];
									}
									
									echo $sub_total;
									$total = $total+$sub_total;
									?>
								</td>
							</tr>
							
							
							<?php 
							endforeach;
							}?>
							
							
							
							<tr>
								<td class="bg3">
									<?php echo $lang['txt_outstanding_invites'];?><br />
									<span class="txt_footer">
									<?php echo $lang['txt_outstanding_invites_intro'];?><br />
									</span>
								</td>
								<td align="center" class="bg2" valign="middle">
									<?php 
									$sub_total = 0;
									if (isset($outstanding_invites) && $outstanding_invites > 0) {
									    $sub_total = $outstanding_invites;
									}
									
									echo $sub_total;
									$total = $total+$sub_total;
									?>
								</td>
							</tr>
							<tr>
								<td class="bg3">
									<?php echo $lang['txt_your_social_network'];?><br />
									<span class="txt_footer">
									<?php echo $lang['txt_your_social_network_intro'];?><br />
									</span>
								</td>
								<td align="center" class="bg1" valign="middle">
									<?php echo $total;?>
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" border="0" cellspacing="0" cellpadding="4">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_social_network1'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($friends)) {
				foreach($friends as $key => $i):
				?>
				<tr>
					<td>

						<table border="0" width="100%" cellspacing="2" cellpadding="2" class="picture">
							<tr>
								<td valign="middle" width="46" align="center" height="28">
									<img src="<?php echo $templatePath;?>img/sn.png" width="28" height="28" alt="" /><br />
								</td>
								<td valign="middle" align="center" width="46" class="bg2">
									<?php echo $i['sn_total'];?><br />
								</td>
								<td valign="middle" class="bg4">
									<table border="0" width="100%" cellspacing="2" cellpadding="0">
										<tr>
											<td>
												<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><b><?php echo $i['profile_nic'];?></b></a>, 
												
												<?php echo $i['profile_create_datetime'];?>, 
												<?php echo $i['profile_hometown'];?>, 
			
												<?php
												if ($i['online_status'] == 1) {
												    echo "<b>" . $lang['arr_user_online_status'][1] . "</b><br />";
												}
												else {
													    echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
												}
												?>
											</td>
											<td align="right">
												<?php
												if (isset($i['profile_allow_msg']) && $i['profile_allow_msg'] == 1) {
												?>
												<a href="msg_compose.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a>&nbsp;&nbsp;<br />
												<?php }?>
											</td>
										</tr>
									</table>
								</td>
								<td valign="middle" width="32">
									<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
								</td>
							</tr>
						</table>


					</td>
				</tr>
				<tr>
					<td colspan="5">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="5">
						<?php echo $lang['err_no_friends'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

		</td>
	</tr>
</table>
